import { Instruction, FSX, Path } from '@ts-schema-autogen/types';
import { MaybeAsyncIterable } from '@ts-schema-autogen/utils';
import { FileRemovalFailure, MultipleFailures, Success } from '@ts-schema-autogen/status';
import { ConfigParser } from './config-parser';
import { ConfigLoader } from './load-config';
/** Determine output files from instruction and delete them */
export declare function cleanUnit(param: cleanUnit.Param): cleanUnit.Return;
export declare namespace cleanUnit {
    interface Param {
        /** `fs-extra` module to perform file deletion */
        readonly fsx: FSX.Mod;
        /** `path` module to resolve paths  */
        readonly path: Path.Mod;
        /** Directory that clean targets belong to */
        readonly directory: string;
        /** Instruction whose output files need to be deleted */
        readonly instruction: Instruction;
    }
    interface ReturnItem {
        /** Path to the deleted file */
        readonly filename: string;
        /** Perform deletion */
        readonly execute: () => Promise<void>;
    }
    type Return = ReturnItem[];
}
/** Determine output files from multiple configs and delete them */
export declare function clean(param: clean.Param): Promise<clean.Return>;
export declare namespace clean {
    export interface Param {
        /** `fs-extra` module to perform file deletion */
        readonly fsx: FSX.Mod;
        /** `path` module to get directory names and resolve paths */
        readonly path: Path.Mod;
        /** Parsers to convert text data to structured data */
        readonly parsers: readonly ConfigParser[];
        /** List of config filenames */
        readonly configFiles: MaybeAsyncIterable<string>;
    }
    type ConfigLoaderFailure = Exclude<ConfigLoader.LoaderReturn, Success<any>>;
    export type Return = MultipleFailures.Maybe<ConfigLoaderFailure | FileRemovalFailure> | Success<void>;
    export {};
}
