import { Config, FSX, Path } from '@ts-schema-autogen/types';
import { ValidationError } from '@ts-schema-autogen/validate';
import { ConfigParser } from './config-parser';
import { FileReadingFailure, TextParsingFailure, CircularReference, MissingFileParser, UnsatisfiedSchema, Success } from '@ts-schema-autogen/status';
/** Error carried by {@link TextParsingFailure} */
export interface ConfigParseError {
    /** Used parser */
    parser: ConfigParser;
    /** Error that `loader.parseConfigText` thrown */
    error: unknown;
}
/** Load a config file */
export declare function loadConfigFile(param: loadConfigFile.Param): Promise<loadConfigFile.Return>;
export declare namespace loadConfigFile {
    interface Param {
        /** `fs-extra` module to read config file */
        readonly fsx: FSX.Mod;
        /** Path to the config file */
        readonly filename: string;
        /** List of parsers to be attempted on the config file */
        readonly parsers: Iterable<ConfigParser>;
    }
    type Return = FileReadingFailure | TextParsingFailure<ConfigParseError> | Success<unknown>;
}
/** Merge a config with extensions */
export declare function mergeConfig(primary: Config, ...inherited: Config[]): Config;
/** Load and cache config files */
export declare class ConfigLoader {
    private readonly param;
    constructor(param: ConfigLoader.ConstructorParam);
    private readonly simpleCache;
    private readonly validator;
    private prvLoadConfig;
    /** Load a config file from cache or from filesystem */
    loadConfig(filename: string): Promise<ConfigLoader.LoaderReturn>;
}
export declare namespace ConfigLoader {
    interface ConstructorParam {
        /** `fs-extra` module to read config files */
        readonly fsx: FSX.Mod;
        /** `path` module */
        readonly path: Path.Mod;
        /** Parsers to be attempted on each config file */
        readonly parsers: readonly ConfigParser[];
    }
    type LoaderReturn = FileReadingFailure | TextParsingFailure<ConfigParseError> | MissingFileParser | CircularReference | UnsatisfiedSchema<ValidationError> | Success<Config>;
}
